@@ -1,3 +1,5 @@
+use super::*;
+
 /// Rase a complex fixed-point number to an real-valued integer power.
 /// `base^power`.
 /// 
@@ -17,15 +19,15 @@
 /// let x = Complex::new( FixedI32::<U22>::from_num(1), FixedI32::<U22>::from_num(1) );
 /// let y = trig::complex::powi( x, 2 );
 /// 
-/// let result = Complex::new( FixedI32::<U22>::from_num( 0.0418525 ), FixedI32::<U22>::from_num( 1.9995792 ));
+/// let result = Complex::new( FixedI32::<U22>::from_num( 0.0417783 ), FixedI32::<U22>::from_num( 1.996042 ));
 /// assert_eq!{ y, result };
 /// ```
 pub fn powi<T>( base: num::complex::Complex<T>, power:usize ) -> num::complex::Complex<T>
-    where T: fixed_sqrt::FixedSqrt + fixed::traits::FixedSigned
+    where T: fixed::traits::FixedSigned
 {   
     // Calculate raised magnitude.
     let temp:T = super::powi( base.re, 2 ) + super::powi( base.im, 2 );
-    let mag:T  = super::powi( temp.sqrt(), power );
+    let mag:T  = super::powi( sqrt::niirf(temp, 2), power );
 
     let phi:T  = super::atan::atan2( base.im, base.re )*<T>::from_num(power);
 
